import React, { useState } from "react";
import {
  TextField,
  Button,
  Card,
  FormControl,
  Grid,
  FormHelperText,
  OutlinedInput,
  Box,
} from "@mui/material";
import { useNavigate } from "react-router-dom";
import toast from "react-hot-toast";
import axios from "axios";
import { isAutheticated } from "src/auth";

const styles = {
  formStyle: {
    fontWeight: "700",
    fontSize: "12px",
    fontFamily: "inter",
    marginBottom: "3px",
    marginLeft: "0",
  },
  topRightButton: {
    position: "absolute",
    top: "10px",
    right: "10px",
  },
};

const AddPrincipalDistributor = () => {
  const navigate = useNavigate();
  const [user, setUser] = useState({
    name: "",
    email: "",
    password: "",
    phone: "",
  });
  const [id, setUserId] = useState("");
  const token = isAutheticated();

  const [loading, setLoading] = useState(false);
  const [data, setData] = useState({
    street: "",
    city: "",
    state: "",
    postalCode: "",
    country: "",
    company_name: "",
    gst_number: "",
  });

  const handleChange = (e) => {
    setData((prev) => ({ ...prev, [e.target.name]: e.target.value }));
  };

  const handleInputChanges = (e) => {
    setUser({ ...user, [e.target.name]: e.target.value });
  };

  const handleAddressSubmit = (e) => {
    e.preventDefault();
    if (
      data.street === "" ||
      data.city === "" ||
      data.state === "" ||
      data.postalCode === "" ||
      data.country === ""
    ) {
      toast.error("Please fill all mandatory fields.");
      return;
    }
    setLoading(true);
    axios
      .post(
        `/api/shipping/address/admin/new/${id}`,
        { ...data },
        {
          headers: {
            "Access-Control-Allow-Origin": "*",
            Authorization: `Bearer ${token}`,
          },
        }
      )
      .then((res) => {
        setLoading(false);
        navigate("/principal-distributor");
        toast.success(res.data.message ? res.data.message : "Address Added!");
      })
      .catch((error) => {
        setLoading(false);
        toast.error(
          error.response.data.message
            ? error.response.data.message
            : "Something went wrong!"
        );
      });
  };

  const generatePassword = (name, email) => {
    const combinedStr = (name + email).toLowerCase();
    const specialChars = "@#*";
    const alphaChars = combinedStr.match(/[a-zA-Z]/g);
    const filteredChars = combinedStr.match(/[^\W_]/g);
    let passwordChars = alphaChars.concat(filteredChars);

    const specialChar = specialChars.charAt(
      Math.floor(Math.random() * specialChars.length)
    );
    const randomIndex = Math.floor(Math.random() * (passwordChars.length + 1));
    passwordChars.splice(randomIndex, 0, specialChar);

    passwordChars = passwordChars.sort(() => Math.random() - 0.5);
    const password = passwordChars.join("").slice(0, 8);
    return password;
  };

  const handleFormSubmit = async (e) => {
    e.preventDefault();
    try {
      if (!user.name || !user.email || !user.phone) {
        throw new Error("Fill all fields!");
      }

      const generatedPassword = generatePassword(user.name, user.email);
      setUser({ ...user, password: generatedPassword });

      const response = await axios.post("/api/v1/user/register", {
        ...user,
        password: generatedPassword,
      });
      if (response.status === 201) {
        toast.success("User Added Successfully");
        // console.log(response.data);
        setUserId(response.data.userId);
      }
    } catch (error) {
      console.log(error.response.data.message);
      toast.error(error.response.data.message);
    }
  };

  const handleCancel = () => {
    navigate("/principal-distributor");
  };

  return (
    <div>
      <Card
        sx={{ padding: "1rem", marginBottom: "1rem", position: "relative" }}
      >
        <Button
          variant="outlined"
          color="secondary"
          onClick={handleCancel}
          sx={styles.topRightButton}
        >
          Cancel
        </Button>

        <form style={{ marginBottom: "2rem" }} onSubmit={handleFormSubmit}>
          <TextField
            id="name"
            required
            type="text"
            sx={{ marginBottom: "2rem", width: "50%" }}
            name="name"
            value={user.name}
            label="Name"
            variant="outlined"
            onChange={handleInputChanges}
          />
          <br />
          <TextField
            id="email"
            type="email"
            sx={{ mb: "2rem", width: "50%" }}
            required
            name="email"
            value={user.email}
            label="Email"
            variant="outlined"
            onChange={handleInputChanges}
          />
          <br />
          <TextField
            id="phone"
            type="tel"
            sx={{ mb: "2rem", width: "50%" }}
            required
            name="phone"
            value={user.phone}
            label="Mobile Number"
            variant="outlined"
            onChange={handleInputChanges}
          />
          <br />
          <Button variant="contained" disabled={id?.length > 0} type="submit">
            Add Principal Distributor
          </Button>
          <br />
        </form>

        <form onSubmit={handleAddressSubmit}>
          <Grid container spacing={2}>
            <Grid item xs={12}>
              <FormControl variant="outlined" fullWidth>
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  STREET ADDRESS*
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="Street Address"
                  aria-describedby="outlined-weight-helper-text"
                  name="street"
                  required
                  type="text"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={12}>
              <FormControl variant="outlined" fullWidth>
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  COUNTRY*
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="Country"
                  aria-describedby="outlined-weight-helper-text"
                  name="country"
                  required
                  type="text"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={12}>
              <FormControl fullWidth variant="outlined">
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  TOWN CITY*
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="Town City"
                  aria-describedby="outlined-weight-helper-text"
                  name="city"
                  required
                  type="text"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={6}>
              <FormControl variant="outlined" fullWidth>
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  STATE*
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="State"
                  aria-describedby="outlined-weight-helper-text"
                  name="state"
                  required
                  type="text"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={6}>
              <FormControl variant="outlined" fullWidth>
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  ZIP CODE*
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="Zip Code"
                  aria-describedby="outlined-weight-helper-text"
                  name="postalCode"
                  required
                  type="number"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={12}>
              <FormControl variant="outlined" fullWidth>
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  Company Name
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="Company name"
                  aria-describedby="outlined-weight-helper-text"
                  name="company_name"
                  type="text"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={12}>
              <FormControl variant="outlined" fullWidth>
                <FormHelperText
                  id="outlined-weight-helper-text"
                  sx={styles.formStyle}
                >
                  GST Number
                </FormHelperText>
                <OutlinedInput
                  size="small"
                  id="outlined-adornment-weight"
                  placeholder="GST Number"
                  aria-describedby="outlined-weight-helper-text"
                  name="gst_number"
                  type="text"
                  onChange={handleChange}
                />
              </FormControl>
            </Grid>
            <Grid item xs={12}>
              <Button
                variant="contained"
                disabled={!id?.length > 0}
                type="submit"
              >
                Submit
              </Button>
            </Grid>
          </Grid>
        </form>
      </Card>
    </div>
  );
};

export default AddPrincipalDistributor;
